@@ -10,28 +10,37 @@ env = config.envs.env
 logging=logger.get_logger(name='mlops_model_manager')
 
 
-mlops_dataset_id = None
+dataset_id = 'mlops'
 
 
-def setup(cdf_api_keys=None, dataset='mlops'):
+def setup(cdf_api_keys=None, dataset_external_id='mlops'):
     """
     Set up the model manager. This involves setting up the CDF client and the
     dataset used to store artifacts.
     
     Input:
         - cdf_api_keys: dictionary with cdf keys
-        - dataset: (str) external id for the dataset (use None for no dataset)
+        - dataset_external_id: (str) external id for the dataset (use None 
+            for no dataset)
     """
     if cdf_api_keys:
         cdf.api_keys = cdf_api_keys
     cdf.set_up_cdf_client()
-    if dataset:
-        global mlops_dataset_id
-        mlops_dataset_id = cdf.get_dataset_id(dataset)
-        if mlops_dataset_id:
-            logging.debug(f"{dataset=}, {mlops_dataset_id=}")
-        else:
-            raise ValueError(f"Didn't find {dataset=}")
+    set_active_dataset(dataset_external_id)
+
+
+def set_active_dataset(external_id):
+    """
+    Set current active dataset
+    
+    Input:
+        - external_id: (str) external id for the dataset (use None for no
+            dataset)
+    """
+    global dataset_id
+    dataset_id = cdf.get_dataset_id(external_id)
+    m = f"Active dataset: {external_id=}, {dataset_id=}"
+    logging.debug(m)
 
 
 def upload_new_model_version(model_name, env, folder, metadata={}):
@@ -54,7 +63,7 @@ def upload_new_model_version(model_name, env, folder, metadata={}):
         external_id_prefix= f"{model_name}/{env}/", 
         directory_prefix='/mlops', 
         uploaded=None, # count any file
-        dataset_id=mlops_dataset_id
+        dataset_id=dataset_id
     )
     if not file_list.empty:
         latest_v = file_list.metadata.apply(lambda d:int(d["version"])).max()
@@ -78,7 +87,7 @@ def upload_new_model_version(model_name, env, folder, metadata={}):
         folder, 
         metadata,
         target_folder='/mlops',
-        dataset_id=mlops_dataset_id
+        dataset_id=dataset_id
     )
     logging.info(f"Uploaded model with {external_id=} from {folder}")
     return folder_info
@@ -100,7 +109,7 @@ def find_model_version(model_name, env, metadata):
         directory_prefix='/mlops', 
         external_id_prefix=f"{model_name}/{env}",
         metadata=metadata,
-        dataset_id=mlops_dataset_id
+        dataset_id=dataset_id
     )
 
     if (n_models := file_list.shape[0]) == 0:
@@ -181,7 +190,7 @@ def get_model_version_overview(model_name=None, env=None, metadata={}):
         external_id_prefix=None,
         uploaded=None,
         metadata=metadata,
-        dataset_id=mlops_dataset_id
+        dataset_id=dataset_id
     )
 
     # query the external id
@@ -191,6 +200,9 @@ def get_model_version_overview(model_name=None, env=None, metadata={}):
     if env:
         index = file_list.externalId.str.contains("/" + env + "/")
         file_list = file_list.loc[index]
+    if not dataset_id:
+        index = file_list.dataSetId.isnull()
+        file_list = file_list.loc[index]
     return file_list
 
 
@@ -259,7 +271,7 @@ def promote_model(model_name, version, confirm=True):
         - version: (int or str) model's version in test
     """
     external_id = f"{model_name}/test/{version}"
-    if not cdf.file_exists(external_id, '/mlops', dataset_id=mlops_dataset_id):
+    if not cdf.file_exists(external_id, '/mlops', dataset_id):
         return
 
     confirmed = False
@@ -269,4 +281,4 @@ def promote_model(model_name, version, confirm=True):
 
     target_ext_id = f"{model_name}/prod/{version}"
     if not confirm or confirmed:
-        cdf.copy_file(external_id, target_ext_id, dataset_id=mlops_dataset_id)
\ No newline at end of file
+        cdf.copy_file(external_id, target_ext_id, dataset_id=dataset_id)
\ No newline at end of file
